# Introduction
Juma Shafara
2024-10-30

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## RTV Pie

> RTV pie is a new python package for automating internal data
> preprocessing for analysis and machine learning for Raising The
> Village

## Table of Contents

0.  [Installation](00_installation.ipynb)
1.  [Setting up dotenv (`.env`)](01_setting_up_dotenv.ipynb)
2.  [Downloading files(artifacts) to Weights and Biases
    (wandb)](02_1_uploading_to_wandb.ipynb)
3.  [Uploading files(artifacts) to Weights and Biases
    (wandb)](02_2_uploading_to_wandb.ipynb)
4.  [Getting variable decordings](03_getting_meanings.ipynb)
5.  [Manipulate datasets](manipulate.ipynb)

more to follow …
